# ugot
A JupyterLab extension for ugot

## Requirements

* jupyterlab >= 3.0
* concurrent-log-handler
* grpcio
* protobuf
* grpcio-tools
* wheel
* zeroconf

## Install

```bash
pip install ugot
```

## Uninstall

```bash
pip uninstall ugot
```


